@@ -7,6 +7,8 @@ SETUPTOOLS_RUST = dirname(dirname(dirname(__file__)))
 
 @nox.session()
 def test(session: nox.Session):
-    session.install(SETUPTOOLS_RUST, "pytest")
+    session.install(SETUPTOOLS_RUST, "wheel", "pytest")
+    # Ensure build uses version of setuptools-rust under development
     session.install("--no-build-isolation", ".")
+    # Test Python package
     session.run("pytest", *session.posargs)
